# Migration Guides

This section provides some guides to aid in migrating software from
earlier versions _NNG_ or _libnanomsg_.

- [Migrating from NNG 1.x](./migrate/nng1.md)
- [Migrating from libnanomsg](./migrate/nanomsg.md)
